posthoc.vanWaerden.test(x, ...)## S3 method for class 'default':
posthoc.vanWaerden.test( x, g, p.adjust.method =
p.adjust.methods, \dots)
## S3 method for class 'formula':
posthoc.vanWaerden.test(formula, data, subset,
na.action, p.adjust.method = p.adjust.methods, \dots)
x. Ignored if x is a
list.response ~ group where
response gives the data values and group a vector or
factor of the corresponding groups.model.frame) containing the variables in the
formula formula. By default the variables are taken from
environment(formulNAs. Defaults to
getOption("na.action").p.adjust)."PMCMR"vanWaerden.test using normal scores can be
employed. Provided that significant differences were detected by this
global test, one may be interested in applying post-hoc tests according
to van der Waerden for pairwise multiple comparisons of the group levels.First, the data are ranked according to Kruskal-Wallis. Second, the ranks are transformed to normal scores. The group means of normal scores and the total variance is used to calculate quantiles of the student-t-distribution and consequent p-values.
See vignette("PMCMR") for details.
kruskal.test,
vanWaerden.test,
posthoc.kruskal.nemenyi.test,
posthoc.kruskal.dunn.test,
TDist,
p.adjust##
require(stats)
data(InsectSprays)
attach(InsectSprays)
vanWaerden.test(count, spray)
posthoc.vanWaerden.test(count, spray, "bonferroni")
detach(InsectSprays)
rm(InsectSprays)Run the code above in your browser using DataLab